]> Raphaƫl G. Git Repositories - acme/blobdiff - Acme.pm
Add last raw file
[acme] / Acme.pm
diff --git a/Acme.pm b/Acme.pm
index e8679c14834094c43840b045818891b5c5bd3f3d..236038027c9274f8ff7b5cbede8f54bb9d7e9336 100644 (file)
--- a/Acme.pm
+++ b/Acme.pm
@@ -66,7 +66,7 @@ use constant {
        CONFIG => '/etc/acme/config',
        PENDING => '/tmp/acme',
        THUMBPRINT => '/etc/acme/thumbprint',
-       TERM => 'https://letsencrypt.org/documents/LE-SA-v1.2-November-15-2017.pdf',
+       TERM => 'https://letsencrypt.org/documents/LE-SA-v1.3-September-21-2022.pdf',
        MAIL => 'webmaster',
 
        # Certificate info
@@ -97,7 +97,7 @@ use constant {
        ACME_PROD_DIR => 'https://acme-v02.api.letsencrypt.org/directory',
 
        # Version
-       VERSION => '2.0.2',
+       VERSION => '2.0.4',
 
        # Timeout
        TIMEOUT => 300
@@ -1063,11 +1063,14 @@ sub issue {
                write_file($file, $content);
        }
 
-       # Remove first multi-line jump
-       $content =~ s/\n\n/\n/;
+       # Write to raw cert file
+       write_file($self->{domain}{cert}.'.raw', $content);
+
+       # Remove multi-line jump
+       $content =~ s/\n\n/\n/s;
 
        # Remove ISRG Root X1 certificate signed by DST Root CA X3 present after second multi-line jump
-       $content =~ s/\n\n.*//s;
+       #$content =~ s/\n\n.*//s;
 
        # Remove trailing line jump
        chomp $content;